==> ukui-sidebar_4.0.1.6.orig.tar.gz: ukui-sidebar-4.0.1.6/translations/ukui-sidebar_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>CollapsedList</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/CollapsedList.qml" line="279"/>
        <source>%1 more notifications</source>
        <translation>还有%1则通知</translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <source>Show less</source>
        <translation type="vanished">折叠</translation>
    </message>
</context>
<context>
    <name>MessageBoxGroup</name>
    <message>
        <source>Rencent messages</source>
        <translation type="vanished">最近消息</translation>
    </message>
    <message>
        <source>Notification Center</source>
        <translation type="vanished">通知中心</translation>
    </message>
    <message>
        <source>No new notifications</source>
        <translation type="vanished">没有新通知</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="vanished">清空</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>No new notifications received</source>
        <translation type="vanished">没有收到新通知</translation>
    </message>
</context>
<context>
    <name>MessageHeaderTips</name>
    <message>
        <source>Notification Center</source>
        <translation type="vanished">通知中心</translation>
    </message>
    <message>
        <source>No new notifications</source>
        <translation type="vanished">没有新通知</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="vanished">清空</translation>
    </message>
    <message>
        <source>Recent Messages</source>
        <translation type="vanished">最近消息</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="vanished">设置</translation>
    </message>
</context>
<context>
    <name>MessageItem</name>
    <message>
        <source>%1 more message</source>
        <translation type="vanished">还有%1则通知</translation>
    </message>
    <message>
        <source>%1 more messages</source>
        <translation type="vanished">还有%1则通知</translation>
    </message>
    <message>
        <source>%1 more message%2</source>
        <translation type="vanished">还有%1则通知</translation>
    </message>
</context>
<context>
    <name>NotificationCenterHeader</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterHeader.qml" line="58"/>
        <source>Notification Center</source>
        <translation>通知中心</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterHeader.qml" line="91"/>
        <source>No new notifications</source>
        <translation>没有新通知</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterHeader.qml" line="132"/>
        <source>Clear All</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>NotificationCenterLabel</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterLabel.qml" line="32"/>
        <source>Notification Center</source>
        <translation>通知中心</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterLabel.qml" line="47"/>
        <source>Clear All</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterLabel.qml" line="90"/>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>NotificationCenterPC</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterPC.qml" line="57"/>
        <source>No new notifications received</source>
        <translation>没有收到新通知</translation>
    </message>
</context>
<context>
    <name>NotificationList</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationList.qml" line="265"/>
        <location filename="../qml/org/ukui/notification/ui/NotificationList.qml" line="267"/>
        <source>%1 more notifications</source>
        <translation>还有%1则通知</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationList.qml" line="491"/>
        <source>Show less</source>
        <translation>折叠</translation>
    </message>
</context>
<context>
    <name>PopupView</name>
    <message>
        <location filename="../qml/PopupView.qml" line="192"/>
        <source>%1 more notifications</source>
        <translation>还有%1则通知</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main/account-information.cpp" line="46"/>
        <source>administrator</source>
        <translation>管理员</translation>
    </message>
    <message>
        <location filename="../src/main/account-information.cpp" line="47"/>
        <source>standard user</source>
        <translation>普通用户</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="250"/>
        <source>Show the current state of the sidebar.</source>
        <translation>显示侧边栏现在的状态</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="251"/>
        <source>There are two options, &apos;notify&apos; and &apos;control&apos;.</source>
        <translation>notify -&gt;打开通知中心，control -&gt; 打开控制中心</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="252"/>
        <source>Quit sidebar.</source>
        <translation>退出侧边栏</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="360"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>ukui-sidebar</source>
        <translation>侧边栏</translation>
    </message>
</context>
<context>
    <name>SideBar::DateTimeUtils</name>
    <message>
        <source>Just now</source>
        <translation type="vanished">刚刚</translation>
    </message>
    <message>
        <source>Within a week</source>
        <translation type="vanished">一周内</translation>
    </message>
    <message>
        <source>Now</source>
        <translation type="vanished">现在</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation type="vanished">昨天 </translation>
    </message>
</context>
<context>
    <name>SideBarApplication</name>
    <message>
        <location filename="../src/side-bar-application.cpp" line="362"/>
        <source>Set up notification center</source>
        <translation>通知中心设置</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="369"/>
        <source>Sidebar</source>
        <translation>侧边栏</translation>
    </message>
    <message>
        <source>ukui-sidebar</source>
        <translation type="vanished">侧边栏</translation>
    </message>
</context>
<context>
    <name>UkuiShortcut::PowerButton</name>
    <message>
        <location filename="../src/main/account-information.cpp" line="215"/>
        <source>power</source>
        <translatorcomment>电源按钮</translatorcomment>
        <translation>电源</translation>
    </message>
</context>
<context>
    <name>Sidebar::DateTimeUtils</name>
    <message>
        <location filename="../src/utils/date-time-utils.cpp" line="108"/>
        <source>Now</source>
        <translation>现在</translation>
    </message>
    <message>
        <location filename="../src/utils/date-time-utils.cpp" line="119"/>
        <location filename="../src/utils/date-time-utils.cpp" line="121"/>
        <source>Yesterday </source>
        <translation>昨天 </translation>
    </message>
</context>
</TS>

==> ukui-sidebar_4.10.0.5.orig.tar.gz: ukui-sidebar-4.10.0.5/translations/ukui-sidebar_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>CollapsedList</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/CollapsedList.qml" line="279"/>
        <source>%1 more notifications</source>
        <translation>还有%1则通知</translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <source>Show less</source>
        <translation type="vanished">折叠</translation>
    </message>
</context>
<context>
    <name>MessageBoxGroup</name>
    <message>
        <source>Rencent messages</source>
        <translation type="vanished">最近消息</translation>
    </message>
    <message>
        <source>Notification Center</source>
        <translation type="vanished">通知中心</translation>
    </message>
    <message>
        <source>No new notifications</source>
        <translation type="vanished">没有新通知</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="vanished">清空</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>No new notifications received</source>
        <translation type="vanished">没有收到新通知</translation>
    </message>
</context>
<context>
    <name>MessageHeaderTips</name>
    <message>
        <source>Notification Center</source>
        <translation type="vanished">通知中心</translation>
    </message>
    <message>
        <source>No new notifications</source>
        <translation type="vanished">没有新通知</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="vanished">清空</translation>
    </message>
    <message>
        <source>Recent Messages</source>
        <translation type="vanished">最近消息</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="vanished">设置</translation>
    </message>
</context>
<context>
    <name>MessageItem</name>
    <message>
        <source>%1 more message</source>
        <translation type="vanished">还有%1则通知</translation>
    </message>
    <message>
        <source>%1 more messages</source>
        <translation type="vanished">还有%1则通知</translation>
    </message>
    <message>
        <source>%1 more message%2</source>
        <translation type="vanished">还有%1则通知</translation>
    </message>
</context>
<context>
    <name>NotificationCenterHeader</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterHeader.qml" line="58"/>
        <source>Notification Center</source>
        <translation>通知中心</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterHeader.qml" line="91"/>
        <source>No new notifications</source>
        <translation>没有新通知</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterHeader.qml" line="132"/>
        <source>Clear All</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>NotificationCenterLabel</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterLabel.qml" line="32"/>
        <source>Notification Center</source>
        <translation>通知中心</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterLabel.qml" line="47"/>
        <source>Clear All</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterLabel.qml" line="90"/>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>NotificationCenterPC</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationCenterPC.qml" line="61"/>
        <source>No new notifications received</source>
        <translation>没有收到新通知</translation>
    </message>
</context>
<context>
    <name>NotificationList</name>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationList.qml" line="293"/>
        <location filename="../qml/org/ukui/notification/ui/NotificationList.qml" line="295"/>
        <source>%1 more notifications</source>
        <translation>还有%1则通知</translation>
    </message>
    <message>
        <location filename="../qml/org/ukui/notification/ui/NotificationList.qml" line="532"/>
        <source>Show less</source>
        <translation>折叠</translation>
    </message>
</context>
<context>
    <name>PopupView</name>
    <message>
        <location filename="../qml/PopupView.qml" line="207"/>
        <source>%1 more notifications</source>
        <translation>还有%1则通知</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main/account-information.cpp" line="46"/>
        <source>Administrator</source>
        <translation>管理员</translation>
    </message>
    <message>
        <location filename="../src/main/account-information.cpp" line="47"/>
        <source>Standard user</source>
        <translation>普通用户</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="206"/>
        <source>Show the current state of the sidebar.</source>
        <translation>显示侧边栏现在的状态</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="207"/>
        <source>There are two options, &apos;notify&apos; and &apos;control&apos;.</source>
        <translation>notify -&gt;打开通知中心，control -&gt; 打开控制中心</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="208"/>
        <source>Quit sidebar.</source>
        <translation>退出侧边栏</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="317"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>ukui-sidebar</source>
        <translation>侧边栏</translation>
    </message>
</context>
<context>
    <name>SideBar::DateTimeUtils</name>
    <message>
        <source>Just now</source>
        <translation type="vanished">刚刚</translation>
    </message>
    <message>
        <source>Within a week</source>
        <translation type="vanished">一周内</translation>
    </message>
    <message>
        <source>Now</source>
        <translation type="vanished">现在</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation type="vanished">昨天 </translation>
    </message>
</context>
<context>
    <name>SideBarApplication</name>
    <message>
        <location filename="../src/side-bar-application.cpp" line="319"/>
        <source>Set up notification center</source>
        <translation>通知中心设置</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="326"/>
        <source>Sidebar</source>
        <translation>侧边栏</translation>
    </message>
    <message>
        <source>ukui-sidebar</source>
        <translation type="vanished">侧边栏</translation>
    </message>
    <message>
        <location filename="../src/side-bar-application.cpp" line="365"/>
        <source>%1 Notifications</source>
        <translation>%1 条通知</translation>
    </message>
</context>
<context>
    <name>Sidebar::DateTimeUtils</name>
    <message>
        <location filename="../src/utils/date-time-utils.cpp" line="108"/>
        <source>Now</source>
        <translation>现在</translation>
    </message>
    <message>
        <location filename="../src/utils/date-time-utils.cpp" line="119"/>
        <location filename="../src/utils/date-time-utils.cpp" line="121"/>
        <source>Yesterday </source>
        <translation>昨天 </translation>
    </message>
</context>
<context>
    <name>UkuiShortcut::PowerButton</name>
    <message>
        <location filename="../src/main/account-information.cpp" line="215"/>
        <source>Power</source>
        <translatorcomment>电源按钮</translatorcomment>
        <translation>电源</translation>
    </message>
</context>
</TS>
